IneligibleToken class

Constructors

IneligibleToken({required String symbol, required double amount, double? amountInFiat, String? ineligibilityReason})
const
IneligibleToken.fromJson(Map<String, dynamic> json)
factory

Properties

amount double
final
amountInFiat double?
final
hashCode int
The hash code for this object.
no setterinherited
ineligibilityReason String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbol String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited