TransferExecutedEvent class

Inheritance

Constructors

TransferExecutedEvent({required TransferExecutedStatus status, required String txId, required String fromAddress, required String toAddress, required String symbol, required double amount, required String networkId, String? userId, String? clientTransactionId})
const
TransferExecutedEvent.fromJson(Map<String, dynamic> json)
factory

Properties

amount double
final
clientTransactionId String?
final
fromAddress String
final
hashCode int
The hash code for this object.
no setterinherited
networkId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status TransferExecutedStatus
final
symbol String
final
toAddress String
final
txId String
final
userId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited