mesh_sdk_flutter library
Classes
- AccessTokenPayload
- Account
- AccountToken
- BaseSuccessPayload
- BrandInfo
- ConnectionDeclinedEvent
- CredentialsEnteredEvent
- DelayedAuthPayload
- ExecuteFundingStepEvent
- FundingOptionsUpdatedEvent
- FundingOptionsViewedEvent
- GasIncreaseWarningEvent
- HomePageMethodSelectedEvent
- IneligibleToken
- Integration
- IntegrationAccessToken
- Represents an access token for a specific integration.
- IntegrationAccountSelectionRequiredEvent
- IntegrationConnectedEvent
- IntegrationConnectedPayload
- IntegrationConnectionErrorEvent
- IntegrationMfaEnteredEvent
- IntegrationOAuthStartedEvent
- IntegrationSelectedEvent
- IntegrationSuccessPayload
- LegalTermsViewedEvent
- LinkTransferQrGeneratedEvent
- LoadedEvent
- MeshConfiguration
- Configuration for the Mesh SDK.
- MeshError
- MeshEvent
- Represents an event that can occur in the Mesh SDK.
- MeshLocalizations
-
Callers can lookup localized strings with an instance of MeshLocalizations
returned by
MeshLocalizations.of(context). - MeshResult
- Represents the result of MeshSdk.show. This can either be a MeshSuccess or a MeshError.
- MeshSdk
- Entry point for the Mesh SDK. Use this class to show the Mesh Link with your configuration.
- MeshSuccess
- NetworkFee
- SeeWhatHappenedClickedEvent
- SuccessPayload
- Transfer
- TransferAmountEnteredEvent
- TransferAssetSelectedEvent
- TransferConfigureErrorEvent
- TransferDeclinedEvent
- TransferExecutedEvent
- TransferExecutionErrorEvent
- TransferFinishedErrorPayload
- TransferFinishedEvent
- TransferFinishedPayload
- TransferFinishedSuccessPayload
- TransferInitiatedEvent
- TransferKycRequiredEvent
- TransferMfaEnteredEvent
- TransferMfaRequiredEvent
- TransferNetworkSelectedEvent
- TransferNoEligibleAssetsEvent
- TransferPreviewedEvent
- TransferPreviewErrorEvent
- TransferStartedEvent
- TransferSuccessPayload
- VerifyDonePageEvent
- VerifyWalletRejectedEvent
- WalletMessageSignedEvent
Enums
- HomePageMethod
- MeshErrorType
- Fatal errors that can occur inside Mesh SDK.
- TransferExecutedStatus
Functions
-
lookupMeshLocalizations(
Locale locale) → MeshLocalizations